@@ -202,8 +202,8 @@ def load_dataset(path_metadata_file: str,
             continue
 
         if idx_target is None:
-            list_data.append(Data(x=crystal_graph, dtype=DTYPE_CSTRUCT))
+            list_data.append(Data(x=crystal_graph, idx=i, dtype=DTYPE_CSTRUCT))
         else:
-            list_data.append(Data(x=crystal_graph, y=metadata[i, idx_target], dtype=DTYPE_CSTRUCT))
+            list_data.append(Data(x=crystal_graph, y=metadata[i, idx_target], idx=i, dtype=DTYPE_CSTRUCT))
 
     return Dataset(list_data, idx_mat_id=idx_mat_id, idx_target=idx_target, atomic_cutoff=atomic_cutoff)
